/*
 * Copyright (c) 2007 The Xfce Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA
 */

#ifndef __LIBXFCE4UI_H__
#define __LIBXFCE4UI_H__

#include <libxfce4util/libxfce4util.h>

#define _LIBXFCE4UI_INSIDE_LIBXFCE4UI_H

#include <libxfce4ui/libxfce4ui-config.h>
#include <libxfce4ui/xfce-dialogs.h>
#include <libxfce4ui/xfce-gdk-extensions.h>
#include <libxfce4ui/xfce-gtk-extensions.h>
#include <libxfce4ui/xfce-spawn.h>
#include <libxfce4ui/xfce-filename-input.h>
#include <libxfce4ui/xfce-sm-client.h>
#include <libxfce4ui/xfce-titled-dialog.h>
#include <libxfce4ui/libxfce4ui-enum-types.h>

#undef _LIBXFCE4UI_INSIDE_LIBXFCE4UI_H

#endif /* !__LIBXFCE4UI_H__ */
